package com.ozs.web.controller.base;

import com.ozs.base.domain.BaseProfessional;
import com.ozs.base.domain.vo.BaseProfessionalVo;
import com.ozs.base.service.BaseProfessionalService;
import com.ozs.common.core.controller.BaseController;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.utils.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 专业库管理
 *
 * @author sunhh
 */
@Api(tags = "专业库管理")
@RestController
@RequestMapping("/base/professional")
public class BaseProfessionalController extends BaseController {

    @Autowired
    private BaseProfessionalService baseProfessionalService;

    @ApiOperation(value = "新增专业库", notes = "必传 专业库名称、一级分类、编码、父级编码；没有父级编码传0")
    @PostMapping("/insertProfessional")
    public AjaxResult insertProfessional(BaseProfessional baseProfessional) {
        if (StringUtils.isNull(baseProfessional) || StringUtils.isNull(baseProfessional.getProfessionalName())
                || StringUtils.isNull(baseProfessional.getProfessionalCode()) || StringUtils.isNull(baseProfessional.getProfessionalGrade())) {
            return error("专业库名称、编码、一级分类不能为空");
        }
        return toAjax(baseProfessionalService.save(baseProfessional));
    }

    @ApiOperation(value = "删除专业库", notes = "必传 id")
    @PostMapping("/deleteProfessional")
    public AjaxResult deleteProfessional(BaseProfessional baseProfessional) {
        if (StringUtils.isNull(baseProfessional) || StringUtils.isNull(baseProfessional.getId())) {
            return error("专业库id不能为空");
        }
        return toAjax(baseProfessionalService.removeById(baseProfessional.getId()));
    }

    @ApiOperation(value = "批量删除专业库", notes = "必传 idList")
    @PostMapping("/deleteIds")
    public AjaxResult deleteByIdLIst(@RequestBody BaseProfessionalVo baseProfessionalVo) {
        baseProfessionalService.deleteIds(baseProfessionalVo.getDeleteIds());
        return success();
    }

    @ApiOperation(value = "修改专业库", notes = "必传 id 及修改数据")
    @PostMapping("/updateProfessional")
    public AjaxResult updateProfessional(BaseProfessional baseProfessional) {
        if (StringUtils.isNull(baseProfessional) || StringUtils.isNull(baseProfessional.getId())) {
            return error("专业库id和修改数据不能为空");
        }
        return toAjax(baseProfessionalService.updateById(baseProfessional));
    }

    @ApiOperation(value = "查询专业库树结构", notes = "非必传 查询条件：品目名称")
    @PostMapping("/selectBaseProfessional")
    public AjaxResult selectBaseProfessional(BaseProfessionalVo baseProfessionalVo) {
        List<BaseProfessionalVo> baseSupplierList = baseProfessionalService.selectBaseProfessional(baseProfessionalVo);
        return success(baseSupplierList);
    }
}
