package com.ozs.plan.doman;


import com.fasterxml.jackson.annotation.JsonFormat;
import com.ozs.common.core.domain.BaseEntity;
import lombok.Data;

import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @author buzhanyi
 */
@Data
public class PlanOfYears extends BaseEntity {

    /**
     * 主键编号
     */
    private Long planYearId;
    /**
     * 采购单位（登录账号的单位）
     */
    @NotNull(message = "采购单位不能为空")
    private Long purchaseUnit;
    /**
     * 项目名称
     */
    @NotNull(message = "项目名称不能为空")
    private String projectName;
    /**
     * 项目类型（1：装备类；2：物资类；3：服务类；）
     */
    @NotNull(message = "项目类型不能为空")
    private String projectType;
    /**
     * 需求概况
     */
    @NotNull(message = "需求概况不能为空")
    private String demandOverview;
    /**
     * 概算金额(万元（保留小数点后两位）
     */
    @NotNull(message = "概算金额不能为空")
    private BigDecimal evaluation;
    /**
     * 是否为超限额计划()
     */
    @NotNull(message = "是否为超限额计划不能为空")
    private String isExcess;
    /**
     * 采购服务站
     */
    @NotNull(message = "采购服务站不能为空")
    private String purchaseServices;
    /**
     * 采购方式
     */
    @NotNull(message = "采购方式不能为空")
    private String purchaseMode;
    /**
     * 计划提报需求时间--->需求单位成功提报采购需求的日期（具体到月）
     */
    @NotNull(message = "计划提报需求时间不能为空")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date demandCommitTime;
    /**
     * 计划完成采购时间--->公示中标结果的日期，即填制中标信息的日期（具体到月）
     */
    @NotNull(message = "计划完成采购时间不能为空")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date purchaseFinishTime;
    /**
     * 计划交付时间--->供应商完成并交付后，使用单位收到标的日期，即填制建设文档的日期
     */
    @NotNull(message = "计划交付时间不能为空")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date deliverTime;
    /**
     * 项目属性--->应急应战项目、重大规划任务项目、规划任务项目或一般项目
     */
    @NotNull(message = "项目属性不能为空")
    private String projectAttribute;
    /**
     * 计划调整情况及理由--->如计划需要变更，在填写申请修改时需填写调整情况及理由，审核单位审核通过后显示
     */
    @NotNull(message = "计划调整情况及理由不能为空")
    private String readjustOfPlan;
    /**
     * 备注
     */
    private String remarks;

    /**
     * 项目状态--->包括计划待提交、计划待审核、计划已退回、计划已审核
     */
    private String projectStatus;
    /**
     * 退回原因--->审核不通过就是退回
     */
    private String reason_of_return;
    /**
     * 创建者
     */
    private String createBy;
    /**
     * 创建时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;
    /**
     * 逻辑删除字段--->（0：正常，1：已删除）
     */
    private Integer isDelete;


}
